@@ -25,7 +25,7 @@ class KLibLoaderTestObject : public QObject
     Q_OBJECT
 public:
     KLibLoaderTestObject(QObject *parent, const QStringList &);
-    ~KLibLoaderTestObject();
+    ~KLibLoaderTestObject() override;
 };
 
 #endif
