@@ -31,7 +31,7 @@ QTEST_GUILESS_MAIN(KStandarddirsTest)
 #include <kglobal.h>
 #include <qtemporarydir.h>
 #include <QDebug>
-#include <QtTest>
+#include <QTest>
 #include <kconfiggroup.h>
 #include <QFile>
 
@@ -62,10 +62,15 @@ void KStandarddirsTest::initTestCase()
         }
     }
 
-    m_configHome = QDir::homePath() + QLatin1String("/.kde-unit-test/xdg/config");
+    // canonicalPath() to resolve symlinks (e.g. on FreeBSD where /home is a symlink to /usr/home),
+    // this matches what KGlobal::dirs()->realPath() would do, but we can't use it before setting
+    // the env vars, it would mess up the unit test
+    const QString homePath = QDir::home().canonicalPath();
+    m_configHome = homePath + QLatin1String("/.kde-unit-test/xdg/config");
+
     qputenv("XDG_CONFIG_HOME", QFile::encodeName(m_configHome));
 
-    m_dataHome = QDir::homePath() + QLatin1String("/.kde-unit-test/xdg/local");
+    m_dataHome = homePath + QLatin1String("/.kde-unit-test/xdg/local");
     qputenv("XDG_DATA_HOME", QFile::encodeName(m_dataHome));
 
     const QString configDirs = QDir::currentPath() + "/xdg";
@@ -455,7 +460,9 @@ void KStandarddirsTest::testSetXdgDataDirs()
     // When setting XDG_DATA_DIRS this should still be true
     const QString localApps = m_dataHome + "/applications/";
     QVERIFY(KStandardDirs::makeDir(localApps));
-    const QString customDataDir = QDir::homePath() + QLatin1String("/.kde-unit-test/xdg/global");
+
+    // canonicalPath: see the comment in initTestCase
+    const QString customDataDir = QDir::home().canonicalPath() + QLatin1String("/.kde-unit-test/xdg/global");
     qputenv("XDG_DATA_DIRS", QFile::encodeName(customDataDir));
     QVERIFY(QDir(customDataDir).mkpath("applications"));
     KStandardDirs newStdDirs;
@@ -523,6 +530,12 @@ void KStandarddirsTest::testRestrictedResources()
 
 void KStandarddirsTest::testSymlinkResolution()
 {
+    // On FreeBSD it is common to have a symlink /home -> /usr/home,
+    // which messes with all the comparisons where **some** code paths
+    // return a canonicalized path and some do not.
+    if (QDir::homePath().compare(QFileInfo(QDir::homePath() + '/').canonicalFilePath(), PATH_SENSITIVITY) != 0) {
+        QSKIP("HOME contains a symlink, not supported");
+    }
 #ifndef Q_OS_WIN
     // This makes the save location for the david resource, "<XDG_DATA_HOME>/symlink/test/"
     // where symlink points to "real", and the subdir test will be created later
@@ -586,3 +599,5 @@ void KStandarddirsTest::testThreads()
     sync.addFuture(QtConcurrent::run(this, &KStandarddirsTest::testRelativeLocation));
     sync.waitForFinished();
 }
+
+#include "moc_kstandarddirstest.cpp"
