@@ -20,7 +20,7 @@
 
 #include "keditlistbox.h"
 
-#include <QtCore/QStringList>
+#include <QStringList>
 #include <QKeyEvent>
 #include <QLabel>
 #include <QLayout>
@@ -92,7 +92,7 @@ void KEditListBoxPrivate::init(bool check, KEditListBox::Buttons newButtons,
 
     setEditor(lineEdit, representationWidget);
 
-    buttons = nullptr;
+    buttons = KEditListBox::Buttons();
     q->setButtons(newButtons);
 
     q->connect(listView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
@@ -673,3 +673,5 @@ bool KEditListBox::eventFilter(QObject *o, QEvent *e)
 
     return false;
 }
+
+#include "moc_keditlistbox.cpp"
