@@ -20,20 +20,18 @@
 
 #include "kpixmapcache.h"
 
-#include <QtCore/QString>
+#include <QString>
 #include <QPixmap>
-#include <QtCore/QFile>
-#include <QtCore/QDataStream>
-#include <QtCore/QFileInfo>
-#include <QtCore/QDateTime>
+#include <QFile>
+#include <QDataStream>
+#include <QFileInfo>
 #include <QPixmapCache>
-#include <QtCore/QtGlobal>
+#include <QtGlobal>
 #include <QPainter>
-#include <QtCore/QQueue>
-#include <QtCore/QTimer>
-#include <QtCore/QMutex>
-#include <QtCore/QMutexLocker>
-#include <QtCore/QList>
+#include <QQueue>
+#include <QTimer>
+#include <QMutex>
+#include <QMutexLocker>
 #include <qdir.h>
 #include <qstandardpaths.h>
 #include <qlockfile.h>
@@ -136,7 +134,7 @@ class KPCMemoryDevice : public QIODevice
 {
 public:
     KPCMemoryDevice(char *start, quint32 *size, quint32 available);
-    virtual ~KPCMemoryDevice();
+    ~KPCMemoryDevice() override;
 
     qint64 size() const override
     {
@@ -904,11 +902,11 @@ bool KPixmapCache::Private::removeEntries(int newsize)
     // Sort the entries according to RemoveStrategy. This moves the best
     //  entries to the beginning of the list
     if (q->removeEntryStrategy() == RemoveOldest) {
-        qSort(entries.begin(), entries.end(), compareEntriesByAge);
+        std::sort(entries.begin(), entries.end(), compareEntriesByAge);
     } else if (q->removeEntryStrategy() == RemoveSeldomUsed) {
-        qSort(entries.begin(), entries.end(), compareEntriesByTimesUsed);
+        std::sort(entries.begin(), entries.end(), compareEntriesByTimesUsed);
     } else {
-        qSort(entries.begin(), entries.end(), compareEntriesByLastUsed);
+        std::sort(entries.begin(), entries.end(), compareEntriesByLastUsed);
     }
 
     // Write some entries to the new files
